"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callCustomMethod = void 0;
const method_utils_1 = require("./method-utils");
const http_method_1 = require("./http-method");
async function callCustomMethod(options) {
    var _a, _b;
    if (!method_utils_1.isMethodEnabled(options.methodName, options, options.forceCall)) {
        throw new Error(`method ${options.methodName} not found in datasource ${(_a = options.dsConfig) === null || _a === void 0 ? void 0 : _a.name}(${(_b = options.dsConfig) === null || _b === void 0 ? void 0 : _b.id}) or not enabled in this datasource`);
    }
    const method = options.handlers[options.methodName];
    const methodCfg = method_utils_1.getMethodCfg(options.dsConfig, options.methodName);
    const isHttp = http_method_1.isHttpMethod(methodCfg);
    if (isHttp) {
        return http_method_1.callHttpMethod({
            methodName: options.methodName,
            dsConfig: options.dsConfig,
            params: options.params,
            methodCfg,
            isTestMode: options.isTestMode,
        }, options.context);
    }
    const result = await method(options.params, options.context);
    return {
        code: 0,
        data: result,
    };
}
exports.callCustomMethod = callCustomMethod;
